@@ -1,6 +1,7 @@
-from abc import ABC, abstractmethod
 from rx.core.typing import Observable
 
+from abc import ABC, abstractmethod
+
 from typing import (
     Dict,
     List,
@@ -15,6 +16,7 @@ from typing import (
     Callable,
     overload,
     TypeVar,
+    AsyncGenerator,
 )
 
 Callback = Callable[..., Any]
@@ -479,6 +481,23 @@ class IceServer(TypedDict):
     credential: Optional[str]
 
 
+class FrameResolution(TypedDict):
+    width: int
+    height: int
+
+
+class FrameMetadata(TypedDict):
+    index: int
+    format: str
+    frameSize: int
+    resolution: FrameResolution
+
+
+class Frame(TypedDict):
+    metadata: FrameMetadata
+    data: bytes
+
+
 # camera storage
 @runtime_checkable
 class CameraStorage(Protocol):
@@ -544,12 +563,12 @@ class StorageController(Protocol):
 # logger
 @runtime_checkable
 class PluginLogger(Protocol):
-    def log(self, *args: Union[str, Dict, Exception]) -> None: ...
-    def error(self, *args: Union[str, Dict, Exception]) -> None: ...
-    def warn(self, *args: Union[str, Dict, Exception]) -> None: ...
-    def attention(self, *args: Union[str, Dict, Exception]) -> None: ...
-    def debug(self, *args: Union[str, Dict, Exception]) -> None: ...
-    def trace(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def log(self, *args) -> None: ...
+    def error(self, *args) -> None: ...
+    def warn(self, *args) -> None: ...
+    def attention(self, *args) -> None: ...
+    def debug(self, *args) -> None: ...
+    def trace(self, *args) -> None: ...
 
 
 # config service
@@ -655,6 +674,7 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
+    async def generate_frames(self) -> AsyncGenerator[Frame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> List[IceServer]: ...
     # async def create_session(self, options: Any) -> Any: ... # todo
